<?php

namespace App\Http\Controllers\admin;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use App\Models\Inquiry;
use App\Models\Businesscard;
use App\Models\User;
use App\Helpers\helper;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Validator;

class InquiryController extends Controller
{
    public function index(Request $request)
    {
        $inquiries = Inquiry::with('business_info')->where('vendor_id', Auth::user()->id)->orderByDesc('id')->get();
        return view('admin.inquiry.inquiry', compact('inquiries'));
    }

    public function store(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required',
            'mobile' => 'required|numeric',
            'email' => 'required|email',
            'message' => 'required',
        ], [
            'name.required' => trans('messages.name_required'),
            'mobile.required' => trans('messages.mobile_required'),
            'email.required' => trans('messages.email_required'),
            'email.email' => trans('messages.valid_email'),
            'message.required' => trans('messages.message_required'),
        ]);
        if ($validator->fails()) {
            return redirect(url()->previous() . '#contact_inquiries')->withErrors($validator)->withInput();
        } else {

            $business = Businesscard::find($request->id);
            $getvendordata = User::select('email', 'name')->where('id', $business->vendor_id)->first();
            $msg = trans('labels.new_inquiry');
            $sendmail = helper::send_inquiry_mail($business->title, $getvendordata->name, $getvendordata->email, $request->name, $request->email, $request->mobile, $request->message, $msg);
            if ($sendmail == 1) {
                $inquiry = new Inquiry;
                $inquiry->vendor_id = $business->vendor_id;
                $inquiry->business_id = $business->id;
                $inquiry->name = $request->name;
                $inquiry->mobile = $request->mobile;
                $inquiry->email = $request->email;
                $inquiry->message = $request->message;
                $inquiry->save();
                return redirect()->back()->with("success", trans('messages.success'));
            } else {
                return redirect()->back()->with("error", trans('messages.error'));
            }
        }
    }
}
